<?php

namespace Drupal\editoria11y;

use Drupal\Core\Database\Connection;
use Drupal\Core\Database\StatementInterface;

/**
 * Handles database calls for DashboardController
 */
class Dashboard
{

    private $database;

    public function __construct(Connection $database)
    {
        $this->database = $database;
    }


    /**
   * @param int $page
   * @param string $header
   *
   * @return array
   */
    public function getResults(int $page = 0, $header = ['page_title'], $range = 50): array
    {
        $num_per_page = $range;
        $offset = $num_per_page * $page;

        $query = $this->database->select('editoria11y_results', 't')
        ->extend('Drupal\\Core\\Database\\Query\\TableSortExtender');
        $query->fields('t')
        ->groupBy('page_path');
        //if ($test) {
        //    $query->condition('result_name', $test);
        //}
        $query
        ->orderByHeader($header)
        ->range($offset, $offset + $num_per_page); // Add table sort extender.
        $total = $this->database->select('editoria11y_results')
        ->fields('editoria11y_results', ['page_path'])
        ->groupBy('page_path');
        $count = $total->countQuery()->execute()->fetchField();

        $results = $query
        ->execute();

        return ["results" => $results, "count" => $count];
    }

    public function getTopResults(): StatementInterface {

        $query = $this->database->select('editoria11y_results');
        $query->fields('editoria11y_results', ['page_result_count', 'page_path', 'page_title'])
        ->groupBy('page_path');
        $query
        ->orderBy('page_result_count', 'desc')
        ->range(0, 15);

        return $query->execute();
    }

  /**
   * @return array
   */
    public function getResultsByIssue($resultKey, $page, $header): array
    {

        $num_per_page = 50;
        $offset = $num_per_page * $page;

        $query = $this->database->select('editoria11y_results', 't')
        ->extend('Drupal\\Core\\Database\\Query\\TableSortExtender');
        $query->fields('t')
        //->fields('editoria11y_results',['page_title','route_name','page_path','result_name_count'])
        ->condition('result_name', $resultKey)
        ->orderByHeader($header);

        $count = $query->countQuery()->execute()->fetchField();
        $results = $query->range($offset, $offset + $num_per_page)->execute();

        return ["results" => $results, "count" => $count];
    }

  /**
   * @return \Drupal\Core\Database\StatementInterface|null
   */
    public function getResultsByPage($resultKey, $header): ?StatementInterface
    {
        $query = $this->database->select('editoria11y_results', 't')
        ->extend('Drupal\\Core\\Database\\Query\\TableSortExtender');
        $query->fields('t')
        //->fields('editoria11y_results',['page_title','route_name','page_path','result_name_count'])
        ->condition('page_path', $resultKey)
        ->orderByHeader($header);

        return $query->execute();
    }

    /**
     * @return \Drupal\Core\Database\StatementInterface|null
     */
    public function getIssueList(): ?StatementInterface
    {
        $query = $this->database->select('editoria11y_results');
        $query->fields('editoria11y_results', ['result_name', 'result_name_count'])
        ->groupBy('result_name')
        ->addExpression('sum(result_name_count)', 'result_name_count');
        $query->orderBy('result_name_count', 'desc');

        return $query->execute();
    }


  /**
   * @return \Drupal\Core\Database\StatementInterface
   */
  public function getRecentDismissals(): StatementInterface {
    $query = $this->database->select('editoria11y_dismissals')
      ->fields('editoria11y_dismissals', ['page_title','page_path','created','result_name','dismissal_status','uid'])
    ->orderBy('created', 'DESC');

    $results = $query->range(0, 5);

    return $results->execute();
  }

    /**
   * @return array
   */
    public function getDismissals($page): array
    {

        $num_per_page = 50;
        $offset = $num_per_page * $page;

        $query = $this->database->select('editoria11y_dismissals')
        ->fields('editoria11y_dismissals', ['page_title','route_name','page_path','created','updated','result_name','dismissal_status','uid','created','updated', 'stale']);

        $count = $query->countQuery()->execute()->fetchField();
        $results = $query->range($offset, $offset + $num_per_page)->execute();

        return ["results" => $results, "count" => $count];
    }
}
